@@ -25,6 +25,7 @@
 
 #include <sys/types.h>
 #include <time.h>
+#include <libgnomevfs/gnome-vfs-result.h>
 #include <libgnomevfs/gnome-vfs-file-size.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
@@ -60,7 +61,7 @@ gboolean            file_move                    (const gchar *from,
 
 gint                file_in_path                 (const gchar *name);
 
-gboolean            ensure_dir_exists            (const gchar *a_path,
+GnomeVFSResult      ensure_dir_exists            (const gchar *a_path,
 						  mode_t       mode);
 
 gboolean            file_is_hidden               (const gchar *name);
@@ -142,5 +143,8 @@ char *              escape_uri                   (const char *uri);
 
 GnomeVFSURI *       new_uri_from_path            (const char *path);
 
+char *              tracktitle_to_filename       (const char *trackname);
+
+gboolean            is_program_in_path           (const char *program_name);
 
 #endif /* FILE_UTILS_H */
